Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Confy ¶
type Confy interface {
Get(key string, ptr interface{}) error
Set(key string, val interface{}) error
Del(key string) error
Keys() ([]string, error)
}
A Confy is a stupid simple configuration store.
type OS ¶ added in v0.7.0
OS is a Confy which uses functionality from package os.
func (*OS) Get ¶ added in v0.7.0
Get loads JSON data into ptr from the file corresponding to the given key.
Click to show internal directories.
Click to hide internal directories.